@@ -1,6 +1,16 @@
+import json
 import unicodedata
 import urllib.parse
 import bs4
+import jsonpath_ng as jsonpath
+
+
+def make_context(url, content_type, content):
+  """Choose the right context based on the content type."""
+  if content_type == 'application/json':
+    return JsonContext(url, JsonContext.parse(url, content))
+  else:
+    return HtmlContext(url, HtmlContext.parse(url, content))
 
 
 class StringContext:
@@ -19,12 +29,9 @@ class StringContext:
 
 
 class HtmlContext:
-  def __init__(self, url, str_or_element):
+  def __init__(self, url, element):
     self.url = url
-    self.element = str_or_element
-
-    if isinstance(str_or_element, str):
-      self.element = self.parse(self.url, self.element)
+    self.element = element
 
   def select(self, selector):
     # Determine whether selector is using ::attr or ::text pseudo-attribute.
@@ -67,3 +74,37 @@ class HtmlContext:
     for br in doc.findAll('br'):
       br.replace_with("\n")
     return doc
+
+
+class JsonContext:
+  def __init__(self, url, json):
+    self.url = url
+    self.json = json
+
+  def select(self, selector):
+    selected = []
+    for match in jsonpath.parse(selector).find(self.json):
+      if isinstance(match.value, str):
+        selected.append(StringContext(self.url, match.value))
+      else:
+        selected.append(JsonContext(self.url, match.value))
+    return selected
+
+  def text(self):
+    return JsonContext.extract_values(self.json)
+
+  @staticmethod
+  def extract_values(json):
+    if isinstance(json, list):
+      return ' '.join(map(JsonContext.extract_values, json))
+    elif isinstance(json, dict):
+      return ' '.join(map(JsonContext.extract_values, json.values()))
+    else:
+      return json
+
+  def __str__(self):
+    return json.dumps(self.json)
+
+  @staticmethod
+  def parse(_url, json_string):
+    return json.loads(json_string)
